@@ -1,8 +1,4 @@
 #!/usr/bin/perl -w
-#
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/socket.pl,v 1.4 2003/05/17 13:31:01 rwmcfa1 Exp $
-#
-
 
 # GTK - The GIMP Toolkit
 # Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
@@ -10,7 +6,7 @@
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,6 +17,9 @@
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 # Boston, MA 02111-1307, USA.
+#
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/socket.pl,v 1.6 2003/09/22 00:04:23 rwmcfa1 Exp $
+#
 
 # this was originally gtk-2.2.1/examples/buttonbox/buttonbox.c
 # ported to gtk2-perl by rm
@@ -54,7 +53,7 @@ if( $pid < 0 )
 }
 if( $pid == 0 )
 {
-	exec(sprintf("perl plug.pl %d\n", $socket->get_id));
+	exec(sprintf("$^X plug.pl %d\n", $socket->get_id));
 }
 
 my $quitbtn = Gtk2::Button->new_from_stock('gtk-quit');
