@@ -145,7 +145,7 @@ sub progressive_timeout {
       #
       my $filename;
 ###      eval { $filename = demo_find_file ("alphatest.png"); };
-      $filename = "alphatest.png";
+      $filename = main::demo_find_file ("alphatest.png");
 #      $filename = "background.jpg";
       if ($@) {
 	  $error_message = $@;
@@ -263,7 +263,8 @@ sub do {
       eval {
         my $filename = "gtk-logo-rgb.gif";
         ##my $filename = demo_find_file ("gtk-logo-rgb.gif");
-        $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file ($filename);
+        $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file (
+		main::demo_find_file ($filename));
       };
 
       if ($@) {
@@ -301,7 +302,7 @@ sub do {
       my $filename;
       eval {
 ##          $filename = demo_find_file ("floppybuddy.gif");
-          $filename = "floppybuddy.gif";
+          $filename = main::demo_find_file ("floppybuddy.gif");
       };
       $image = Gtk2::Image->new_from_file ($filename);
       ##g_free (filename);
@@ -362,3 +363,20 @@ Gtk2->main;
 
 1;
 
+__END__
+Copyright (C) 2003 by the gtk2-perl team (see the file AUTHORS for the
+full list)
+
+This library is free software; you can redistribute it and/or modify it under
+the terms of the GNU Library General Public License as published by the Free
+Software Foundation; either version 2.1 of the License, or (at your option) any
+later version.
+
+This library is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+PARTICULAR PURPOSE.  See the GNU Library General Public License for more
+details.
+
+You should have received a copy of the GNU Library General Public License along
+with this library; if not, write to the Free Software Foundation, Inc., 59
+Temple Place - Suite 330, Boston, MA  02111-1307  USA.
