@@ -1,25 +1,10 @@
 #!/usr/bin/perl -w
 #
-# Copyright (c) 2003 by the gtk team; ported to gtk2-perl 2003 by muppet
-#
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
-# License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
-#
-# You should have received a copy of the GNU Library General Public
-# License along with this library; if not, write to the 
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
-# Boston, MA  02111-1307  USA.
-#
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk-demo/main.pl,v 1.7 2003/07/09 17:42:36 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk-demo/main.pl,v 1.9 2003/09/22 00:04:24 rwmcfa1 Exp $
 #
 
+our $PROGDIR = $0;
+$PROGDIR =~ s/main.pl$//;
 
 use strict;
 use Carp;
@@ -109,10 +94,10 @@ sub demo_find_file {
 	#	       "Cannot find demo data file \"%s\"", base);
 	#  g_free (filename);
 	#  return NULL;
-	use File::Spec;
+#	use File::Spec;
 #	my $filename = File::Spec->catfile (DEMOCODEDIR, $base);
-	my $filename = $base;
-	croak "Cannot find demo data file $base\n"
+	my $filename = $PROGDIR.$base;
+	croak "Cannot find demo data file $base ($filename)\n"
 		unless -e $filename;
 
 	return $filename;
@@ -524,8 +509,9 @@ sub row_activated_cb {
    # pointer again.  it's a kind of hackish lazy loading mechanism.
    # don't try this at home.
    if ('CODE' ne ref $func) {
-       require $filename;
        my $pkg = $filename;
+       $filename = demo_find_file($filename);
+       require $filename;
        $pkg =~ s/\.pl$//;
        eval '$model->set ($iter, FUNC_COLUMN, \&'.$pkg.'::do);';
        ($func) = $model->get ($iter, FUNC_COLUMN);
@@ -709,3 +695,20 @@ $notebook->append_page (create_text (\$source_buffer, TRUE),
 #  load_file ($testgtk_demos[0]{filename});
  
   Gtk2->main;
+__END__
+Copyright (C) 2003 by the gtk2-perl team (see the file AUTHORS for the
+full list)
+
+This library is free software; you can redistribute it and/or modify it under
+the terms of the GNU Library General Public License as published by the Free
+Software Foundation; either version 2.1 of the License, or (at your option) any
+later version.
+
+This library is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+PARTICULAR PURPOSE.  See the GNU Library General Public License for more
+details.
+
+You should have received a copy of the GNU Library General Public License along
+with this library; if not, write to the Free Software Foundation, Inc., 59
+Temple Place - Suite 330, Boston, MA  02111-1307  USA.
