@@ -81,9 +81,18 @@ sub create_model {
                         : '';
 
        $info{macro} = id_to_macro ($info{id});
-      
-       my $iter = $store->append;
-       $store->set ($iter, 0, \%info, 1, $id);
+
+       # something about redhat9's gnome setup registers a whole slew of 
+       # stock items which don't return icons in this context.  i don't
+       # know if it's because we don't do Gnome2::Program->init or what,
+       # but it's really annoying, because it messes with lots of things,
+       # and since you can't pass undef/null for an object property, we
+       # can't tell the cell renderers to use NULL for the pixbufs.
+       # so, we only add an entry for stock items which have icons.
+       if ($info{small_icon}) { 
+         my $iter = $store->append;
+         $store->set ($iter, 0, \%info, 1, $id);
+       }
   }
   return $store;
 }
@@ -101,6 +110,7 @@ sub get_largest_size {
 
   foreach my $size ($set->get_sizes) {
      my ($width, $height) = Gtk2::IconSize->lookup ($size);
+     next unless defined $height;
      if ($width * $height > $best_pixels) {
         $best_size = $size;
 	$best_pixels = $width * $height;
@@ -118,7 +128,7 @@ sub selection_changed {
   my $treeview = $selection->get_tree_view;
   my $display = $treeview->{stock_display};
 
-  my ($iter, $model) = $selection->get_selected;
+  my ($model, $iter) = $selection->get_selected;
   if ($iter) {
       my ($info) = $model->get ($iter, 0);
 
@@ -291,3 +301,20 @@ sub do {
 }
 
 1;
+__END__
+Copyright (C) 2003 by the gtk2-perl team (see the file AUTHORS for the
+full list)
+
+This library is free software; you can redistribute it and/or modify it under
+the terms of the GNU Library General Public License as published by the Free
+Software Foundation; either version 2.1 of the License, or (at your option) any
+later version.
+
+This library is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+PARTICULAR PURPOSE.  See the GNU Library General Public License for more
+details.
+
+You should have received a copy of the GNU Library General Public License along
+with this library; if not, write to the Free Software Foundation, Inc., 59
+Temple Place - Suite 330, Boston, MA  02111-1307  USA.
