@@ -1,3 +1,7 @@
+#
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/pm/Pango.pm,v 1.4 2003/09/22 00:04:24 rwmcfa1 Exp $
+#
+
 package Gtk2::Pango;
 
 use strict;
@@ -100,7 +104,7 @@ This stuff is hardcoded directly from the headers of pango 1.2.1.
 
 =head1 SEE ALSO
 
-perl(1), Gtk2(1)
+perl(1), Gtk2(3pm)
 
 =head1 AUTHOR
 
@@ -113,7 +117,7 @@ Copyright 2003 by muppet
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
+version 2.1 of the License, or (at your option) any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
